@@ -13,8 +13,11 @@ import click
 from prompt_toolkit.shortcuts import PromptSession
 from .sqlexecute import SQLExecute
 from .sqlinternal import Create_file
+from .sqlinternal import Create_SeedCacheFile
 from .sqlcliexception import SQLCliException
 from .commandanalyze import register_special_command
+from .commandanalyze import CommandNotFound
+
 from .__init__ import __version__
 from .sqlparse import SQLAnalyze
 
@@ -56,6 +59,8 @@ class SQLCli(object):
         self.sqlexecute = SQLExecute()
         if logfilename is not None:
             self.logfile = open(logfilename, mode="a", encoding="utf-8")
+            self.sqlexecute.logfile = self.logfile
+        self.sqlexecute.sqlscript = sqlscript
         self.sqlscript = sqlscript
         self.nologo = nologo
         self.logon = logon
@@ -156,11 +161,13 @@ class SQLCli(object):
     # 连接数据库
     def connect_db(self, arg, **_):
         if arg is None:
-            raise SQLCliException("Missing required argument\n." + "connect [user name]/[password]@" +
-                            "jdbc:[db type]:[driver type]://[host]:[port]/[service name]")
+            raise SQLCliException(
+                "Missing required argument\n." + "connect [user name]/[password]@" +
+                "jdbc:[db type]:[driver type]://[host]:[port]/[service name]")
         elif arg == "":
-            raise SQLCliException("Missing required argument\n." + "connect [user name]/[password]@" +
-                            "jdbc:[db type]:[driver type]://[host]:[port]/[service name]")
+            raise SQLCliException(
+                "Missing required argument\n." + "connect [user name]/[password]@" +
+                "jdbc:[db type]:[driver type]://[host]:[port]/[service name]")
         elif self.jar_file is None:
             raise SQLCliException("Please load driver first.")
 
@@ -175,9 +182,10 @@ class SQLCli(object):
             self.db_host = connect_parameters[5]
             self.db_port = connect_parameters[6]
             self.db_service_name = connect_parameters[7]
-            self.db_url = connect_parameters[2] + ':' + connect_parameters[3] + ':' + \
-                          connect_parameters[4] + '://' + connect_parameters[5] + ':' + \
-                          connect_parameters[6] + ':/' + connect_parameters[7]
+            self.db_url = \
+                connect_parameters[2] + ':' + connect_parameters[3] + ':' + \
+                connect_parameters[4] + '://' + connect_parameters[5] + ':' + \
+                connect_parameters[6] + ':/' + connect_parameters[7]
         elif len(connect_parameters) == 2:
             # 用户只指定了用户名和口令， 认为用户和上次保留一直的连接字符串信息
             self.db_username = connect_parameters[0]
@@ -193,9 +201,10 @@ class SQLCli(object):
                         self.db_host = connect_parameters[3]
                         self.db_port = connect_parameters[4]
                         self.db_service_name = connect_parameters[5]
-                        self.db_url = connect_parameters[0] + ':' + connect_parameters[1] + ':' + \
-                                      connect_parameters[2] + '://' + connect_parameters[3] + ':' + \
-                                      connect_parameters[4] + ':/' + connect_parameters[5]
+                        self.db_url = \
+                            connect_parameters[0] + ':' + connect_parameters[1] + ':' +\
+                            connect_parameters[2] + '://' + connect_parameters[3] + ':' + \
+                            connect_parameters[4] + ':/' + connect_parameters[5]
                     else:
                         print(str(connect_parameters))
                         print(len(connect_parameters))
@@ -215,7 +224,7 @@ class SQLCli(object):
                                               self.jar_file, )
             self.sqlexecute.set_connection(self.db_conn)
         except Exception as e:  # Connecting to a database fail.
-            raise SQLCliException(str(e))
+            raise SQLCliException(repr(e))
 
         yield (
             None,
@@ -254,12 +263,16 @@ class SQLCli(object):
             options_parameters = str(arg).split()
             if len(options_parameters) != 2:
                 raise Exception("Missing required argument. set parameter parameter_value.")
-            self.sqlexecute.options[options_parameters[0].upper()] = options_parameters[1].upper()
-            yield (
-                None,
-                None,
-                None,
-                '')
+            # 如果不是已知的选项，则直接抛出到SQL引擎
+            if options_parameters[0].upper() in self.sqlexecute.options:
+                self.sqlexecute.options[options_parameters[0].upper()] = options_parameters[1].upper()
+                yield (
+                    None,
+                    None,
+                    None,
+                    '')
+            else:
+                raise CommandNotFound
 
     # 执行特殊的命令
     def execute_internal_command(self, arg, **_):
@@ -282,6 +295,18 @@ class SQLCli(object):
                 str(matchObj.group(4)) + ' rows created Successful.')
             return
 
+        # 创建随机数Seed的缓存文件
+        matchObj = re.match(r"create\s+seeddatafile(\s+)?;$",
+                            strSQL, re.IGNORECASE)
+        if matchObj:
+            Create_SeedCacheFile()
+            yield (
+                None,
+                None,
+                None,
+                'file created Successful.')
+            return
+
         # 不认识的internal命令
         raise SQLCliException("Unknown internal Command. Please double check.")
 
@@ -404,7 +429,6 @@ class SQLCli(object):
             self.echo("Disconnected.")
 
     def log_output(self, output):
-        """Log the output in the audit log, if it's enabled."""
         if self.logfile:
             click.echo(output, file=self.logfile)
 
@@ -488,7 +512,7 @@ class SQLCli(object):
             output = itertools.chain(output, [title])
 
         if cur:
-            # 列的描述信息，如果不存在，按照None来处理
+            # 列的数据类型，如果不存在，按照None来处理
             column_types = None
             if hasattr(cur, "description"):
                 def get_col_type(col):
